CostModel

Trait CostModel 

pub trait CostModel: Send + Sync {
    // Required methods
    fn gate_cost(&self, gate: &dyn GateOp) -> f64;
    fn circuit_cost_from_gates(&self, gates: &[Box<dyn GateOp>]) -> f64;
    fn weights(&self) -> CostWeights;
    fn is_native(&self, gate: &dyn GateOp) -> bool;

    // Provided method
    fn gates_cost(&self, gates: &[Box<dyn GateOp>]) -> f64 { ... }
}
Trait for cost models

Required Methods

fn gate_cost(&self, gate: &dyn GateOp) -> f64

Calculate the cost of a single gate

fn circuit_cost_from_gates(&self, gates: &[Box<dyn GateOp>]) -> f64

Calculate the total cost of a circuit (using gate list)

fn weights(&self) -> CostWeights

Get the weights used in cost calculation

fn is_native(&self, gate: &dyn GateOp) -> bool

Check if a gate is native on the target hardware

Provided Methods

fn gates_cost(&self, gates: &[Box<dyn GateOp>]) -> f64

Calculate the total cost of a list of gates (alias for circuit_cost_from_gates)

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors