ParallelizationPass

Struct ParallelizationPass 

pub struct ParallelizationPass;
ASAP gate scheduling pass — reorders gates to minimise circuit depth.

Uses Kahn’s topological-sort algorithm. Two gates are dependent if they share at least one qubit. Gates in each layer are emitted in original program order for determinism.

Implementations

Source

impl ParallelizationPass

pub const fn new() -> Self

Create a new ParallelizationPass.