BLAS

Struct BLAS 

pub struct BLAS;

Implementations

Source

impl BLAS

pub fn matrix_approx_equal( a: &SciRSSparseMatrix<Complex64>, b: &SciRSSparseMatrix<Complex64>, tol: f64, ) -> bool

Check whether two sparse matrices are approximately equal entry-wise within tol. For each entry present in either matrix the corresponding value in the other is treated as zero when absent, and the element-wise difference must satisfy |diff| ≤ tol.

pub const fn condition_number(_matrix: &SciRSSparseMatrix<Complex64>) -> f64

pub fn is_symmetric(matrix: &SciRSSparseMatrix<Complex64>, tol: f64) -> bool

pub fn is_hermitian(matrix: &SciRSSparseMatrix<Complex64>, tol: f64) -> bool

pub const fn is_positive_definite( _matrix: &SciRSSparseMatrix<Complex64>, ) -> bool

pub const fn matrix_norm( _matrix: &SciRSSparseMatrix<Complex64>, _norm_type: &str, ) -> f64

pub const fn numerical_rank( _matrix: &SciRSSparseMatrix<Complex64>, _tol: f64, ) -> usize

pub const fn spectral_analysis( _matrix: &SciRSSparseMatrix<Complex64>, ) -> SpectralAnalysis

pub const fn gate_fidelity( _a: &SciRSSparseMatrix<Complex64>, _b: &SciRSSparseMatrix<Complex64>, ) -> f64

pub const fn trace_distance( _a: &SciRSSparseMatrix<Complex64>, _b: &SciRSSparseMatrix<Complex64>, ) -> f64

pub const fn diamond_distance( _a: &SciRSSparseMatrix<Complex64>, _b: &SciRSSparseMatrix<Complex64>, ) -> f64

pub const fn process_fidelity( _a: &SciRSSparseMatrix<Complex64>, _b: &SciRSSparseMatrix<Complex64>, ) -> f64

pub const fn error_decomposition( _a: &SciRSSparseMatrix<Complex64>, _b: &SciRSSparseMatrix<Complex64>, ) -> ErrorDecomposition

pub const fn sparse_matvec( _matrix: &SciRSSparseMatrix<Complex64>, _vector: &VectorizedOps, ) -> QuantRS2Result<VectorizedOps>

pub fn matrix_exp( matrix: &SciRSSparseMatrix<Complex64>, _scale: f64, ) -> QuantRS2Result<SciRSSparseMatrix<Complex64>>