Circuit caching for repeated execution
This module provides sophisticated caching mechanisms for quantum circuits to avoid redundant compilation, optimization, and execution overhead when circuits are reused across multiple invocations.
Structs
- Cache
Config - Cache configuration
- Cache
Entry - Cache entry for compiled circuits
- Cache
Manager - High-level cache manager that coordinates different cache types
- Cache
Stats - Cache statistics
- Circuit
Cache - Generic cache implementation with configurable policies
- Circuit
Signature - Circuit signature for cache key generation
- Signature
Generator - Circuit signature generator for different circuit types
Enums
- Eviction
Policy - Cache eviction policy
Type Aliases
- Compiled
Circuit Cache - Specialized cache for compiled circuits
- Execution
Result Cache - Specialized cache for execution results
- Transpilation
Cache - Specialized cache for transpilation results